changeset 2879:531841047512 lwtools-port

boot_scsi.asm: Fix SCSI ID when booting from SCSI Due to a typo it would probe for SCSI ID 4 instead of default 0 (or 8 for HDBDOS/SuperDriver).
author Tormod Volden <debian.tormod@gmail.com>
date Sun, 24 Nov 2013 16:08:53 +0100
parents 7c46b953e05f
children 0d9bbad2d398
files level1/modules/boot_scsi.asm
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/level1/modules/boot_scsi.asm	Sun Nov 24 16:00:03 2013 +0100
+++ b/level1/modules/boot_scsi.asm	Sun Nov 24 16:08:53 2013 +0100
@@ -44,7 +44,7 @@
 *   5      2012/11/05-06  Gene Heskett
 * SDMPI from defs/scsi.d is being ignored, so boot failed is the message.
 * Ded the object to fix that AND the NULL bus address and this code broken.
 * WhichDrv is now a zero based decimal value passed in by the makefile via IT.DNS
 * Thanks Boisy...
                NAM       Boot                
                TTL       SCSI Boot Module    
@@ -297,7 +297,7 @@
 		ENDC
 Address        FDB       SDAddr
 * So now, this can be a base zero decimal value!
-WhichDrv	FCB	IT.DNS
+WhichDrv	FCB	ITDNS
                EMOD      
 eom            EQU       *
                END
@@ -44,7 +44,7 @@
 * SDMPI from defs/scsi.d is being ignored, so boot failed is the message.
 * Ded the object to fix that AND the NULL bus address and this code broken.
-* WhichDrv is now a zero based decimal value passed in by the makefile via IT.DNS
+* WhichDrv is now a zero based decimal value passed in by the makefile via ITDNS
 * Thanks Boisy...
                NAM       Boot                